lookmix_design_system

A new Flutter project.

Getting Started

This project is a starting point for a Flutter application.

A few resources to get you started if this is your first Flutter project:

For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.

Libraries

hooks/use_disclosure
hooks/use_theme
lookmix_design_system
main
tokens/breakpoints
tokens/tokens
utils/deep_partial
DeepPartial ทำให้ทุก property ของ T เป็น optional แบบ recursive ใช้สำหรับ data class หรือ Map<String, dynamic> แบบ nested