ThemeController class
Constructors
- ThemeController(BuildContext context)
Properties
- context → BuildContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDark → bool
-
no setter
- isLight → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → JpjoyTheme
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setThemeMode(
bool darkMode) → void -
toggleTheme(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited